@@ -464,7 +464,7 @@ If optional argument SERVICE is non-nil, open by the service name."
       ;; notify the real nickname to the user.
       (or liece-real-nickname
 	  (setq liece-real-nickname
-		(truncate-string liece-nickname liece-nick-max-length)))
+		(truncate-string-to-width liece-nickname liece-nick-max-length)))
       (setq liece-nickname-last liece-real-nickname
 	    liece-nick-accepted 'sent
 	    liece-after-registration t))))
